#region Copyright Syncfusion Inc. 2001-2019.
// Copyright Syncfusion Inc. 2001-2019. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Syncfusion.WinForms.DataGrid;
using Syncfusion.XlsIO;
using System.IO;
using Syncfusion.WinForms.DataGridConverter;
using Syncfusion.WinForms.DataGridConverter.Events;
using Syncfusion.Pdf.Graphics;

namespace StackedHeaderRows
{
    public partial class Form1 : Form
    {
        #region Constructor
        public Form1()
        {
            InitializeComponent();
            OrderInfoCollection collection = new OrderInfoCollection();
            sfDataGrid.DataSource = collection.OrdersListDetails;
            GridSettings();
        }

        #endregion

        #region Grid Settings

        /// <summary>
        /// Grid Settings for better Look and Feel.
        /// </summary>
        private void GridSettings()
        {
            var stackedHeaderRow = new StackedHeaderRow();
            stackedHeaderRow.StackedColumns.Add(new StackedColumn() { ChildColumns = "OrderID,CustomerID,ProductName,OrderDate,Quantity,UnitPrice,ContactNumber,ShipCountry", HeaderText = "Order Shipment Details" });
            sfDataGrid.StackedHeaderRows.Add(stackedHeaderRow);

            var stackedHeaderRow1 = new StackedHeaderRow();
            stackedHeaderRow1.StackedColumns.Add(new StackedColumn() { ChildColumns = "OrderID,OrderDate", HeaderText = "Order Details" });
            stackedHeaderRow1.StackedColumns.Add(new StackedColumn() { ChildColumns = "CustomerID,ContactNumber,", HeaderText = "Customer Details" });
            stackedHeaderRow1.StackedColumns.Add(new StackedColumn() { ChildColumns = "ProductName,Quantity,UnitPrice,ShipCountry", HeaderText = "Product Details" });

            sfDataGrid.StackedHeaderRows.Add(stackedHeaderRow1);

            sfDataGrid.Style.StackedHeaderStyle.BackColor = Color.LightGray;
            sfDataGrid.Style.StackedHeaderStyle.TextColor = Color.Red;
        }

        #endregion

        private void Form1_Load(object sender, System.EventArgs e)
        {

        }

        private void button2_Click(object sender, System.EventArgs e)
        {
            PdfExportingOptions ExportOptions = new PdfExportingOptions();
            ExportOptions.Exporting += ExportOptions_Exporting;
            ExportOptions.ExportStackedHeaders = true;

            var document = sfDataGrid.ExportToPdf(ExportOptions);

            SaveFileDialog sfd = new SaveFileDialog
            {
                Filter = "PDF Files(*.pdf)|*.pdf",
                FileName = "document1"
            };

            if (sfd.ShowDialog() == DialogResult.OK)
            {
                using (Stream stream = sfd.OpenFile())
                    document.Save(stream);

                if (MessageBox.Show("Do you want to view the workbook?", "Workbook has been created", MessageBoxButtons.OKCancel) == DialogResult.OK)
                    System.Diagnostics.Process.Start(sfd.FileName);
            }
        }

        private void ExportOptions_Exporting(object sender, DataGridPdfExportingEventArgs e)
        {
            if (e.CellType == ExportCellType.StackedHeaderCell)
            {
                e.CellStyle.BackgroundBrush = PdfBrushes.LightGray;
                e.CellStyle.TextBrush = PdfBrushes.Red;
            }
        }

        private void button1_Click(object sender, System.EventArgs e)
        {
            ExcelExportingOptions GridExcelExportingOptions = new ExcelExportingOptions();
            GridExcelExportingOptions.Exporting += GridExcelExportingOptions_Exporting1;

            var excelEngine = sfDataGrid.ExportToExcel(sfDataGrid.View, GridExcelExportingOptions);
            var workBook = excelEngine.Excel.Workbooks[0];
            SaveFileDialog sfd = new SaveFileDialog
            {
                FilterIndex = 2,
                Filter = "Excel 97 to 2003 Files(*.xls)|*.xls|Excel 2007 to 2010 Files(*.xlsx)|*.xlsx",
                FileName = "Book1"
            };

            if (sfd.ShowDialog() == DialogResult.OK)
            {
                using (Stream stream = sfd.OpenFile())
                {
                    if (sfd.FilterIndex == 1)
                        workBook.Version = ExcelVersion.Excel97to2003;
                    else
                        workBook.Version = ExcelVersion.Excel2010;
                    workBook.SaveAs(stream);
                }

                //Message box confirmation to view the created spreadsheet.
                if (MessageBox.Show("Do you want to view the workbook?", "Workbook has been created", MessageBoxButtons.OKCancel) == DialogResult.OK)
                {
                    //Launching the Excel file using the default Application.[MS Excel Or Free ExcelViewer]
                    System.Diagnostics.Process.Start(sfd.FileName);
                }
            }
        }


        private void GridExcelExportingOptions_Exporting1(object sender, DataGridExcelExportingEventArgs e)
        {
            if (e.CellType == ExportCellType.StackedHeaderCell)
            {
                e.CellStyle.BackGroundColor = sfDataGrid.Style.StackedHeaderStyle.BackColor; // or you can assign the RGB color
                e.CellStyle.ForeGroundColor = sfDataGrid.Style.StackedHeaderStyle.TextColor;
                e.Handled = true;
            }
        }
    }
}
